Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AttachCoreToLogger ¶
AttachCoreToLogger attaches sentry to zap logger
func NewCore ¶
func NewCore(cfg Configuration, factory SentryClientFactory) (zapcore.Core, error)
NewCore creates new zapcore object
Types ¶
type ClientGetter ¶ added in v1.0.1
ClientGetter interface getter for sentry client
type Configuration ¶
type Configuration struct {
Tags map[string]string
DisableStacktrace bool
Level zapcore.Level
FlushTimeout time.Duration
Hub *sentry.Hub
}
Configuration is a minimal set of parameters for Sentry integration.
type SentryClientFactory ¶
SentryClientFactory function that return sentry client
func NewSentryClientFromClient ¶
func NewSentryClientFromClient(client *sentry.Client) SentryClientFactory
NewSentryClientFromClient creates new sentry client from sentry client reference
func NewSentryClientFromDSN ¶
func NewSentryClientFromDSN(DSN string) SentryClientFactory
NewSentryClientFromDSN creates new sentry client from DSN value
Click to show internal directories.
Click to hide internal directories.